@@ -256,14 +256,20 @@ class Database {
 		// build up connection string
 		$driver = 'mysql';
 		$dsn = $driver.":";
-		$options = array('PDO::MYSQL_ATTR_INIT_COMMAND' => 'set names utf8');
+		$options = array(PDO::MYSQL_ATTR_INIT_COMMAND => 'set names utf8');
 		$attributes = array('ATTR_ERRMODE' => 'ERRMODE_EXCEPTION');
 
 		$dbconf["dsn"] = array(
-				'host' => $host,
-				'dbname' => $sql["db"]
+				'dbname' => $sql["db"],
+				'charset' => 'utf8'
 		);
 
+		if (!validateLocalHostname($host) && !validate_ip2($host, true, 'invalidip', true, true)) {
+			$dbconf["dsn"]['unix_socket'] = makeCorrectFile($host);
+		} else {
+			$dbconf["dsn"]['host'] = $host;
+		}
+
 		self::$_dbname = $sql["db"];
 
 		// add options to dsn-string
@@ -297,7 +303,7 @@ class Database {
 	 * @param bool $showerror if set to false, the error will be logged but we go on
 	 */
 	private static function _showerror($error, $showerror = true) {
-		global $userinfo, $settings, $theme, $linker;
+		global $userinfo, $theme, $linker;
 
 		/**
 		 * log to a file, so we can actually ask people for the error
@@ -331,9 +337,11 @@ class Database {
 			// include userdata.inc.php
 			require FROXLOR_INSTALL_DIR."/lib/userdata.inc.php";
 
+			// fallback
+			$theme = 'Sparkle';
+
 			// le format
-			if (self::$_needroot == true
-				&& isset($sql['root_user'])
+			if (isset($sql['root_user'])
 				&& isset($sql['root_password'])
 				&& (!isset($sql_root) || !is_array($sql_root))
 			) {
@@ -355,7 +363,7 @@ class Database {
 			unset($sql_root);
 
 			if ((isset($theme) && $theme != '')
-				&& !isset($_SERVER['SHELL']) || (isset($_SERVER['SHELL']) && $_SERVER['SHELL'] == '')
+					&& !isset($_SERVER['SHELL']) || (isset($_SERVER['SHELL']) && $_SERVER['SHELL'] == '')
 			) {
 				// if we're not on the shell, output a nice error
 				$_errtpl = dirname($sl_dir).'/templates/'.$theme.'/misc/dberrornice.tpl';
@@ -364,11 +372,12 @@ class Database {
 					// replace values
 					$err_hint = str_replace("<TEXT>", $error_message, $err_hint);
 					$err_hint = str_replace("<DEBUG>", $error_trace, $err_hint);
+					$err_hint = str_replace("<CURRENT_YEAR>", date('Y', time()), $err_hint);
 
 					$err_report_html = '';
 					if (is_array($userinfo) && (
-						($userinfo['adminsession'] == '1' && $settings['system']['allow_error_report_admin'] == '1')
-						|| ($userinfo['adminsession'] == '0' && $settings['system']['allow_error_report_customer'] == '1'))
+							($userinfo['adminsession'] == '1' && Settings::Get('system.allow_error_report_admin') == '1')
+							|| ($userinfo['adminsession'] == '0' && Settings::Get('system.allow_error_report_customer') == '1'))
 					) {
 						$err_report_html = '<a href="<LINK>" title="Click here to report error">Report error</a>';
 						$err_report_html = str_replace("<LINK>", $linker->getLink(array('section' => 'index', 'page' => 'send_error_report', 'errorid' => $errid)), $err_report_html);
