@@ -291,7 +291,7 @@ $lng['admin']['serversettings'] = 'Configurações';
 $lng['admin']['rebuildconf'] = 'Escrever de novo os configs';
 $lng['admin']['stdsubdomain'] = 'Subdomínio padrão';
 $lng['admin']['stdsubdomain_add'] = 'Criar Subdomínio padrão';
-$lng['admin']['phpenabled'] = 'PHP habilitado';
+$lng['admin']['phpenabled'] = 'PHP Habilitado';
 $lng['admin']['deactivated'] = 'Desativado';
 $lng['admin']['deactivated_user'] = 'Desativar usuário';
 $lng['admin']['sendpassword'] = 'Enviar senha';
@@ -395,7 +395,6 @@ $lng['domain']['docroot'] = 'trajeto da linha acima de';
 $lng['domain']['homedir'] = 'diretório da casa';
 $lng['admin']['valuemandatory'] = 'Este valor é imperativo.';
 $lng['admin']['valuemandatorycompany'] = 'Qualquer um "nome" e "nome" o "companhia" deve ser enchido.';
-$lng['admin']['phpenabled'] = 'PHP Habilitado';
 $lng['admin']['webserver'] = 'Servidor Web';
 $lng['serversettings']['nameservers']['title'] = 'Servidores DNS';
 $lng['serversettings']['mxservers']['title'] = 'Servidores de Email';
@@ -746,8 +745,8 @@ $lng['login']['presend'] = 'Resetar senha';
 $lng['login']['email'] = 'Endereço de E-mail';
 $lng['login']['remind'] = 'Resetar minha senha';
 $lng['login']['usernotfound'] = 'Úsuario não encontrado';
-$lng['pwdreminder']['subject'] = 'Froxlor - Reset de Senha';
-$lng['pwdreminder']['body'] = 'Oi %s,\n\nsua senha do Froxlor foi resetada!\nA nova senha é: %p\n\nObrigado,\nequipe Froxlor';
+$lng['mails']['password_reset']['subject'] = 'Reset de Senha';
+$lng['mails']['password_reset']['mailbody'] = 'Oi {USERNAME},\n\nsua senha do Froxlor foi resetada!\nA nova senha é: {LINK}\n\nObrigado,\nequipe Froxlor';
 $lng['pwdreminder']['success'] = 'Redefinição de senha com sucesso. <br /> Você agora deve receber um e-mail com sua nova senha.';
 $lng['serversettings']['allow_password_reset']['title'] = 'Aceita reset de senha por clientes';
 $lng['pwdreminder']['notallowed'] = 'Reset de senhas está desativado';
