@@ -1,4 +1,4 @@
-<?php
+<?php if (!defined('MASTER_CRONJOB')) die('You cannot access this file directly!');
 
 /**
  * This file is part of the Froxlor project.
@@ -15,17 +15,6 @@
  *
  */
 
-/*
- * This script creates the php.ini's used by mod_suPHP+php-cgi
- */
-
-if(@php_sapi_name() != 'cli'
-&& @php_sapi_name() != 'cgi'
-&& @php_sapi_name() != 'cgi-fcgi')
-{
-	die('This script only works in the shell.');
-}
-
 class lighttpd_fcgid extends lighttpd
 {
 	protected function composePhpOptions($domain)
@@ -34,11 +23,11 @@ class lighttpd_fcgid extends lighttpd
 
 		if($domain['phpenabled'] == '1')
 		{
-			$php = new phpinterface($this->getDB(), $this->settings, $domain);
+			$php = new phpinterface($domain);
 			$phpconfig = $php->getPhpConfig((int)$domain['phpsettingid']);
 
 			// vhost data for php-fpm
-			if((int)$this->settings['phpfpm']['enabled'] == 1)
+			if((int)Settings::Get('phpfpm.enabled') == 1)
 			{
 				$php_options_text = '  fastcgi.server = ( '."\n";
 				$php_options_text.=	"\t".'".php" => ('."\n";
@@ -51,7 +40,7 @@ class lighttpd_fcgid extends lighttpd
 				$php_options_text.=	'  )'."\n";				
 			}
 			// vhost data for fcgid
-			elseif((int)$this->settings['system']['mod_fcgid'] == 1)
+			elseif((int)Settings::Get('system.mod_fcgid') == 1)
 			{
 				$php_options_text = '  fastcgi.server = ( '."\n";
 				$file_extensions = explode(' ', $phpconfig['file_extensions']);
@@ -74,7 +63,7 @@ class lighttpd_fcgid extends lighttpd
 						}
 						else
 						{
-							$php_options_text.=	"\t\t\t".'"PHP_FCGI_CHILDREN" => "' . (int)$this->settings['system']['mod_fcgid_starter'] . '",'."\n";
+							$php_options_text.=	"\t\t\t".'"PHP_FCGI_CHILDREN" => "' . (int)Settings::Get('system.mod_fcgid_starter') . '",'."\n";
 						}
 					}
 	
@@ -90,7 +79,7 @@ class lighttpd_fcgid extends lighttpd
 						}
 						else
 						{
-							$php_options_text.=	"\t\t\t".'"PHP_FCGI_MAX_REQUESTS" => "' . (int)$this->settings['system']['mod_fcgid_maxrequests'] . '"'."\n";
+							$php_options_text.=	"\t\t\t".'"PHP_FCGI_MAX_REQUESTS" => "' . (int)Settings::Get('system.mod_fcgid_maxrequests') . '"'."\n";
 						}
 					}
 	
@@ -105,8 +94,8 @@ class lighttpd_fcgid extends lighttpd
 			// create starter-file | config-file
 			$php->getInterface()->createConfig($phpconfig);
 			
-			// create php.ini 
-			// @TODO make php-fpm support this
+			// create php.ini (fpm does nothing here, as it
+			// defines ini-settings in its pool config)
 			$php->getInterface()->createIniFile($phpconfig);
 		}
 		else
@@ -119,23 +108,23 @@ class lighttpd_fcgid extends lighttpd
 
 	public function createOwnVhostStarter()
 	{
-		if ($this->settings['phpfpm']['enabled'] == '1'
-			&& $this->settings['phpfpm']['enabled_ownvhost'] == '1'
+		if (Settings::Get('phpfpm.enabled') == '1'
+			&& Settings::Get('phpfpm.enabled_ownvhost') == '1'
 		) {
 			$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__)))); // /var/www/froxlor, needed for chown
 
-			$user = $this->settings['phpfpm']['vhost_httpuser'];
-			$group = $this->settings['phpfpm']['vhost_httpgroup'];	
+			$user = Settings::Get('phpfpm.vhost_httpuser');
+			$group = Settings::Get('phpfpm.vhost_httpgroup');	
 
 			$domain = array(
 				'id' => 'none',
-				'domain' => $this->settings['system']['hostname'],
+				'domain' => Settings::Get('system.hostname'),
 				'adminid' => 1, /* first admin-user (superadmin) */
 				'mod_fcgid_starter' => -1,
 				'mod_fcgid_maxrequests' => -1,
 				'guid' => $user,
 				'openbasedir' => 0,
-				'email' => $this->settings['panel']['adminmail'],
+				'email' => Settings::Get('panel.adminmail'),
 				'loginname' => 'froxlor.panel',
 				'documentroot' => $mypath
 			);
@@ -145,16 +134,22 @@ class lighttpd_fcgid extends lighttpd
 			safe_exec('chown -R ' . $user . ':' . $group . ' ' . escapeshellarg($mypath));
 						
 			// get php.ini for our own vhost
-			$php = new phpinterface($this->getDB(), $this->settings, $domain);
+			$php = new phpinterface($domain);
 
-			// @FIXME don't use fcgid settings, but we don't have anything else atm
-			$phpconfig = $php->getPhpConfig($this->settings['system']['mod_fcgid_defaultini_ownvhost']);
+			// get php-config
+			if (Settings::Get('phpfpm.enabled') == '1') {
+				// fpm
+				$phpconfig = $php->getPhpConfig(Settings::Get('phpfpm.vhost_defaultini'));
+			} else {
+				// fcgid
+				$phpconfig = $php->getPhpConfig(Settings::Get('system.mod_fcgid_defaultini_ownvhost'));
+			}
 
 			// create starter-file | config-file
 			$php->getInterface()->createConfig($phpconfig);
 			
-			// create php.ini 
-			// @TODO make php-fpm support this
+			// create php.ini (fpm does nothing here, as it
+			// defines ini-settings in its pool config)
 			$php->getInterface()->createIniFile($phpconfig);
 		}
 	}
